@@ -141,7 +141,7 @@ impl Agent {
     /// # }
     /// ```
     pub fn request_url(&self, method: &str, url: &Url) -> Request {
-        Request::with_url(self.clone(), method.into(), url.clone())
+        Request::new(self.clone(), method.into(), url.to_string())
     }
 
     /// Make a GET request from this agent.
@@ -235,9 +235,7 @@ impl AgentBuilder {
                     self.max_idle_connections_per_host,
                 ),
                 #[cfg(feature = "cookies")]
-                cookie_tin: CookieTin::new(
-                    self.cookie_store.unwrap_or_else(|| CookieStore::default()),
-                ),
+                cookie_tin: CookieTin::new(self.cookie_store.unwrap_or_else(CookieStore::default)),
                 resolver: self.resolver,
             }),
         }
