@@ -180,10 +180,9 @@ impl error::Error for Error {
 
 impl error::Error for Transport {
     fn source(&self) -> Option<&(dyn error::Error + 'static)> {
-        match &self.source {
-            Some(s) => Some(s.as_ref()),
-            None => None,
-        }
+        self.source
+            .as_ref()
+            .map(|s| s.as_ref() as &(dyn error::Error + 'static))
     }
 }
 
