@@ -3,6 +3,7 @@ use std::io::Result as IoResult;
 use std::net::{SocketAddr, ToSocketAddrs};
 use std::sync::Arc;
 
+/// A custom resolver to override the default DNS behavior.
 pub trait Resolver: Send + Sync {
     fn resolve(&self, netloc: &str) -> IoResult<Vec<SocketAddr>>;
 }
@@ -51,9 +52,3 @@ impl std::ops::Deref for ArcResolver {
         self.0.as_ref()
     }
 }
-
-impl Default for ArcResolver {
-    fn default() -> Self {
-        StdResolver.into()
-    }
-}
