@@ -1,15 +1,16 @@
-#[cfg(any(feature = "tls", feature = "native-tls"))]
+#[cfg(feature = "tls")]
 use std::io::Read;
 
-#[cfg(any(feature = "tls", feature = "native-tls"))]
+#[cfg(feature = "tls")]
 use super::super::*;
 
 #[test]
-#[cfg(any(feature = "tls", feature = "native-tls"))]
+#[cfg(feature = "tls")]
 fn read_range() {
     let resp = get("https://ureq.s3.eu-central-1.amazonaws.com/sherlock.txt")
         .set("Range", "bytes=1000-1999")
-        .call();
+        .call()
+        .unwrap();
     assert_eq!(resp.status(), 206);
     let mut reader = resp.into_reader();
     let mut buf = vec![];
